<?php

/**
 * @file
 * Class file for TradeMeItem
 */

/**
 * Class to descibe an item for sale on trademe. This class contains a lot of
 * attributes, some of them are optional for a given auction
 */
class TradeMeItem {

  // defaults
  public $ListingId = '';
  public $Title = '';
  public $Category = '';
  public $StartPrice = 0;
  public $BuyNowPrice = 0;
  public $StartDate = 0;
  public $EndDate = 0;
  public $ListingLength = '';
  public $AsAt = 0;
  public $CategoryPath = '';
  public $PictureHref = '';
  public $PhotoId = '';
  public $RegionId = '';
  public $Region = '';
  public $Suburb = '';
  public $Seller = NULL;
  public $Buyer = NULL;
  public $Note = '';
  public $NoteId = 0;
  public $NoteDate = 0;
  public $CategoryName = '';
  public $ReserveState = '';
  public $IsClassified = FALSE;
  public $AuctionAttribute = '';
  public $BuyerFeedbackPlaced = FALSE;
  public $SellerFeedbackPlaced = FALSE;
  public $DeliveryId = 0;
  public $FpoDecisionViaMobile = FALSE;
  public $HasPaidByCreditCard = FALSE;
  public $InvoiceId = 0;
  public $OfferId = 0;
  public $PaymentInfo = FALSE;
  public $Price = 0;
  public $ShippingPrice = 0;
  public $SoldDate = 0;
  public $SoldType = '';
  public $IsDailyDeal = FALSE;
  public $Restrictions = 0;
  public $BidderAndWatchers = 0;
  public $MaxBidAmount = 0;
  public $BidCount = 0;
  public $ViewCount = 0;
  public $IsReserveMet = FALSE;
  public $HasReserve = FALSE;
  public $ReservePrice = 0;
  public $SalePrice = 0;
  public $SelectedShipping = FALSE;
  public $BuyerDeliveryAddress = '';
  public $MessageFromBuyer = '';
  public $SuccessFees = 0;
  public $IsPayNowPurchase = FALSE;
  public $HasSellerPlaceFeedback = FALSE;
  public $HasBuyerPlaceFeedback = FALSE;
  public $DeliveryAddress = '';
  public $HasGallery = FALSE;
  public $IsNew = FALSE;
  public $Status = '';
  public $StatusDate = 0;
  public $HasPayNow = FALSE;
  public $HasScheduledEndDate = FALSE;
  public $Attributes = '';
  public $Attribute = '';
  public $OpenHomes = '';
  public $Body = '';
  public $PaymentOptions = '';
  public $AllowsPickups = '';
  public $ShippingOptions = NULL;
  public $Photos = NULL;
  public $PhotosThumbnail = '';
  public $PhotosList = '';
  public $PhotosMedium = '';
  public $PhotosGallery = '';
  public $PhotosLarge = '';
  public $PhotosFullSize = '';
  public $Questions = NULL;
  public $Bids = NULL;
  public $BidsTotalCount = NULL;
  public $BidsPage = NULL;
  public $BidsPageSize = NULL;
  public $BidList = array();
  public $Member = NULL;
  public $RelistedItemId = 0;
  public $HasExtraPhotos = FALSE;
  public $IsProduct = FALSE;
  public $IsFeatured = FALSE;
  public $IsBold = FALSE;
  public $Subtitle = '';

  // generated items
  public $url = '';

  // default constructor
  public function __construct($item = NULL) {

    // loop through each attribute and assign to the object
    foreach ($item->children() as $attribute) {

      $name = $attribute->getName();
      $value = (string) $attribute;

      // only assign the attribute if it is available
      if (property_exists(get_class($this), $name)) {

        // store booleans as such
        if ($value == 'true') {
          $value = (bool) TRUE;
        }
        elseif ($value == 'false') {
          $value = (bool) FALSE;
        }

        // special cases for timestamps, store them as epoch so drupal can
        // format them for display easier later on down the track
        if (drupal_substr($name, -4, 4) == 'Date' || $name == 'AsAt') {
          $this->{$name} = strtotime($value);
        }
        // special case for the seller - use an object, also set buyer to NULL
        elseif ($name == 'Seller') {
          require_once('TradeMePerson.inc');
          $this->{$name} = new TradeMePerson($attribute);
        }
        // special case for the buyer - use an object, also set seller to NULL
        elseif ($name == 'Buyer') {
          require_once('TradeMePerson.inc');
          $this->{$name} = new TradeMePerson($attribute);
        }
        // special case for the member
        elseif ($name == 'Member') {
          require_once('TradeMePerson.inc');
          $this->{$name} = new TradeMePerson($attribute);
        }
        // special case for the bids
        elseif ($name == 'Bids') {
          $this->BidsTotalCount = (string) $attribute->TotalCount;
          $this->BidsPage = (string) $attribute->Page;
          $this->BidsPageSize = (string) $attribute->PageSize;
          require_once('TradeMeBid.inc');
          foreach ($attribute->List->children() as $bid) {
            $this->BidsList[] = new TradeMeBid($bid);
          }
        }
        elseif ($name == 'Attributes') {
          require_once('TradeMeAttribute.inc');
          $this->{$name} = new TradeMeAttribute($attribute);
        }
        // Photos are special, do not want to create a new sub object for these
        // so expand them out to make attributes. These attributes exist when
        // the listing API is called
        elseif ($name == 'Photos') {
          // check to see if there actually are photos (can be blank)
          if (isset($attribute->Photo)) {
            $this->PhotoId = (string) $attribute->Photo->PhotoId;
            foreach ($attribute->Photo->Value->children() as $photo) {
              $photo_name = $photo->getName();
              $photo_url = (string) $photo;
              if ($photo_name != 'PhotoId') {
                $this->{'Photos' . $photo_name} = $photo_url;
              }
            }
          }
        }
        // the api escapes the title attribute for us, this string is HTML safe
        elseif ($name == 'Title') {
          $this->{$name} = $value;
        }
        // no special case reached, just store the value verbatim
        else {
          // check plain is used to encode special HTML characters, I am unsure
          // or what sanitisation the API does, but best to be safe
          $this->{$name} = check_plain($value);
        }
      }
      else {
        watchdog('trademe_api', 'Failed to store the attribute: %name with value: %value in object: %object - please submit patch to address this', array(
          '%name' => $name,
          '%value' => $value,
          '%object' => get_class($this),
        ));
      }
    }
    // compute some elements
    $this->url = 'http://www.trademe.co.nz/' . $this->ListingId;

    // MaxBidAmount is empty if you are the buyer and you have won and auction
    // through an actual bid. Fix this in this object rather than having to fix
    // it in the application
    if (empty($this->MaxBidAmount) && !empty($this->Price)) {
      $this->MaxBidAmount = $this->Price;
    }

    // MaxBidAmount is empty if the auction was won with a buy now, fix this in
    // this object rather than having to fix it in the application
    if (empty($this->MaxBidAmount) && !empty($this->BuyNowPrice)) {
      $this->MaxBidAmount = $this->BuyNowPrice;
    }
  }

  // prettier toString()
  public function __toString() {
    return $this->Title . ' (#' . $this->ListingId . ')';
  }
}
